        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>29</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,9,10,11,12,13,14,18,21,23,24,26,28,29,30,31,33,35,36,37,38,39,41,45,46,47,48,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>4,7,8,15,16,17,19,20,22,25,27,32,34,40,42,43,44';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>29</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,9,10,11,12,13,14,18,21,23,24,26,28,29,30,31,33,35,36,37,38,39,41,45,46,47,48,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>4,7,8,15,16,17,19,20,22,25,27,32,34,40,42,43,44';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>29</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,9,10,11,12,13,14,18,21,23,24,26,28,29,30,31,33,35,36,37,38,39,41,45,46,47,48,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>4,7,8,15,16,17,19,20,22,25,27,32,34,40,42,43,44';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>29</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,9,10,11,12,13,14,18,21,23,24,26,28,29,30,31,33,35,36,37,38,39,41,45,46,47,48,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>4,7,8,15,16,17,19,20,22,25,27,32,34,40,42,43,44';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>29</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,5,6,9,10,11,12,13,14,18,21,23,24,26,28,29,30,31,33,35,36,37,38,39,41,45,46,47,48,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260525 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 17 <br>4,7,8,15,16,17,19,20,22,25,27,32,34,40,42,43,44';}
}
